{inputs, pkgs, ...}: 
{
    # required to autoload fonts from packages installed via Home Manager
    fonts.fontconfig.enable = true;

    # waybar requires font-awesome
    home.packages = [
        pkgs.font-awesome
        pkgs.fira-code
    ];

    # enable waybar
    programs.waybar.enable = true;
    programs.waybar = {
        settings = {
        
            mainBar = {
                margin-top = 5;
                margin-bottom = 5;
                margin-left = 5;
                margin-right = 5;
                height = 42;
                layer = "top";
                position = "top";
                # height = 30;
                # output = [
                #     "eDP-1"
                #     "HDMI-A-1"
                # ];
                modules-left = [
                    "hyprland/workspaces"
                    "hyprland/window"

                ];
                modules-center = [
                    "clock"
                ];
                modules-right = [
                    "tray"
                    # "temperature"
                    "group/expand"
                    "bluetooth"
                    # "network"
                    "mpd"
                    "battery"
                    "backlight"
                    "custom/notification"
                ];

                # module specific settings
                "hyprland/workspaces" = {
                    format = "{icon}";
                    format-icons = {
                        active = "";
                        default = "";
                        empty = "";
                    };
                };
                "custom/notification" = {
                    tooltip = false;
                    format = "";
                    on-click = "swaync-client -t -sw";
                    escape = true;
                };
                "clock" = {
                    format = "{:%H:%M}";
                    interval = 1;   
                    tooltip-format = "<tt>{calendar}</tt>";
                    calendar = {
                        "format" = {
                            "today" = "<span color='#fAfBfC'><b>{}</b></span>";
                        };
                    };
                };

                # "network" = {
                #     "format-wifi" = "";
                #     "format-ethernet" ="";
                #     "format-disconnected" = "";
                #     "tooltip-format-disconnected" = "Error";
                #     "tooltip-format-wifi" = "{essid} ({signalStrength}%) ";
                #     "tooltip-format-ethernet" = "{ifname} 🖧 ";
                #     "on-click" = "kitty nmtui";
                # };
                "bluetooth" = {
                    format-on = "󰂯";
                    format-off = "BT-off";
                    format-disabled = "󰂲";
                    format-connected-battery = "{device_battery_percentage}% 󰂯";
                    format-alt = "{device_alias} 󰂯";
                    tooltip-format = "{controller_alias}\t{controller_address}\n\n{num_connections} connected";
                    tooltip-format-connected = "{controller_alias}\t{controller_address}\n\n{num_connections} connected\n\n{device_enumerate}";
                    tooltip-format-enumerate-connected = "{device_alias}\n{device_address}";
                    tooltip-format-enumerate-connected-battery = "{device_alias}\n{device_address}\n{device_battery_percentage}%";
                    on-click-right = "blueman-manager";
                }; 
                "battery" = {
                    interval = 60;
                    states = {
                        good = 80;
                        warning = 30;
                        critical = 10;
                    };
                    format = "{capacity}% {icon}";
                    format-charging = "{capacity}% 󰂄";
                    format-plugged = "{capacity}% 󰂄 ";
                    format-alt = "{time} {icon}";
                    format-icons = [ "󰁻" "󰁼" "󰁾" "󰂀" "󰂂" "󰁹" ];
                };
            };
        };

        style = ''
            * {
                border: none;
                border-radius: 5px;
                padding: 0px 5px 0px 5px;
                margin: 0px 5px 0px 5px;
                font-size: 18px;
            }
            window#waybar {
                background-color: transparent;
            }
            #workspaces button {
                padding-left: 1px;
                padding-right: 1px;
            }
            #workspaces {
                padding-left: 1px;
                padding-right: 1px;
            }
        '';
        # font-family: ${font};
        # font-weight: ${font_weight};
        # opacity: ${opacity};
        # font-size: ${font_size};

    };
}
    